@@ -162,20 +162,22 @@ main(int argc, char **argv)
         GDK_THREADS_ENTER();
         gtk_main();
         GDK_THREADS_LEAVE();
-
-        g_object_unref (image_list);
     }
     else
     {
         window = rstto_preferences_dialog_new (NULL);
         while (gtk_dialog_run (GTK_DIALOG(window)) == GTK_RESPONSE_HELP)
         {
-            rstto_launch_help ();
+            xfce_dialog_show_help (
+                    GTK_WINDOW (window),
+                    "ristretto",
+                    "preferences",
+                    NULL);
         }
-        gtk_widget_destroy (window);
     }
 
     g_object_unref (settings);
+    g_object_unref (image_list);
 
     xfconf_shutdown();
 
