@@ -54,10 +54,10 @@ static RsttoSettings *settings_object;
 enum
 {
     PROP_0,
-    PROP_SHOW_FILE_TOOLBAR,
-    PROP_SHOW_NAV_TOOLBAR,
+    PROP_SHOW_TOOLBAR,
     PROP_NAVBAR_POSITION,
     PROP_SHOW_THUMBNAILBAR,
+    PROP_SHOW_STATUSBAR,
     PROP_HIDE_THUMBNAILBAR_FULLSCREEN,
     PROP_WINDOW_WIDTH,
     PROP_WINDOW_HEIGHT,
@@ -74,6 +74,7 @@ enum
     PROP_MERGE_TOOLBARS,
     PROP_ERROR_MISSING_THUMBNAILER,
     PROP_SORT_TYPE,
+    PROP_THUMBNAIL_SIZE,
 };
 
 GType
@@ -106,9 +107,9 @@ struct _RsttoSettingsPriv
 {
     XfconfChannel *channel;
 
-    gboolean  show_file_toolbar;
-    gboolean  show_nav_toolbar;
+    gboolean  show_toolbar;
     gboolean  show_thumbnailbar;
+    gboolean  show_statusbar;
     gboolean  hide_thumbnailbar_fullscreen;
     gchar    *navigationbar_position;
     gboolean  revert_zoom_direction;
@@ -124,6 +125,7 @@ struct _RsttoSettingsPriv
     gboolean  use_thunar_properties;
     gboolean  maximize_on_startup;
     gboolean  merge_toolbars;
+    RsttoThumbnailSize thumbnail_size;
 
     RsttoSortType sort_type;
 
@@ -155,16 +157,17 @@ rstto_settings_init (GObject *object)
     settings->priv->bgcolor = g_new0 (GdkColor, 1);
     settings->priv->bgcolor_fullscreen = g_new0 (GdkColor, 1);
     settings->priv->navigationbar_position = g_strdup ("left");
-    settings->priv->show_file_toolbar = TRUE;
-    settings->priv->show_nav_toolbar = TRUE;
+    settings->priv->show_toolbar = TRUE;
     settings->priv->window_width = 600;
     settings->priv->window_height = 440;
     settings->priv->wrap_images = TRUE;
     settings->priv->show_thumbnailbar = TRUE;
+    settings->priv->show_statusbar = TRUE;
     settings->priv->use_thunar_properties = TRUE;
     settings->priv->maximize_on_startup = TRUE;
     settings->priv->hide_thumbnailbar_fullscreen = TRUE;
     settings->priv->errors.missing_thumbnailer = TRUE;
+    settings->priv->thumbnail_size = THUMBNAIL_SIZE_NORMAL;
 
     xfconf_g_property_bind (
             settings->priv->channel,
@@ -191,14 +194,7 @@ rstto_settings_init (GObject *object)
             "/window/toolbar/show",
             G_TYPE_BOOLEAN,
             settings,
-            "show-file-toolbar");
-
-    xfconf_g_property_bind (
-            settings->priv->channel,
-            "/window/navigationbar/show",
-            G_TYPE_BOOLEAN,
-            settings,
-            "show-nav-toolbar");
+            "show-toolbar");
 
     xfconf_g_property_bind (
             settings->priv->channel,
@@ -221,6 +217,20 @@ rstto_settings_init (GObject *object)
             settings,
             "show-thumbnailbar");
 
+    xfconf_g_property_bind (
+            settings->priv->channel,
+            "/window/statusbar/show",
+            G_TYPE_BOOLEAN,
+            settings,
+            "show-statusbar");
+
+    xfconf_g_property_bind (
+            settings->priv->channel,
+            "/window/thumbnails/size",
+            G_TYPE_UINT,
+            settings,
+            "thumbnail-size");
+
     xfconf_g_property_bind (
             settings->priv->channel,
             "/window/thumbnails/hide-fullscreen",
@@ -347,25 +357,14 @@ rstto_settings_class_init (GObjectClass *object_class)
             pspec);
 
     pspec = g_param_spec_boolean (
-            "show-file-toolbar",
+            "show-toolbar",
             "",
             "",
             TRUE,
             G_PARAM_READWRITE);
     g_object_class_install_property (
             object_class,
-            PROP_SHOW_FILE_TOOLBAR,
-            pspec);
-
-    pspec = g_param_spec_boolean (
-            "show-nav-toolbar",
-            "",
-            "",
-            TRUE,
-            G_PARAM_READWRITE);
-    g_object_class_install_property (
-            object_class,
-            PROP_SHOW_NAV_TOOLBAR,
+            PROP_SHOW_TOOLBAR,
             pspec);
 
     pspec = g_param_spec_boolean (
@@ -379,6 +378,17 @@ rstto_settings_class_init (GObjectClass *object_class)
             PROP_SHOW_THUMBNAILBAR,
             pspec);
 
+    pspec = g_param_spec_boolean (
+            "show-statusbar",
+            "",
+            "",
+            TRUE,
+            G_PARAM_READWRITE);
+    g_object_class_install_property (
+            object_class,
+            PROP_SHOW_STATUSBAR,
+            pspec);
+
     pspec = g_param_spec_boolean (
             "hide-thumbnailbar-fullscreen",
             "",
@@ -547,6 +557,19 @@ rstto_settings_class_init (GObjectClass *object_class)
             object_class,
             PROP_SORT_TYPE,
             pspec);
+
+    pspec = g_param_spec_uint (
+            "thumbnail-size",
+            "",
+            "",
+            0,
+            THUMBNAIL_SIZE_COUNT,
+            0,
+            G_PARAM_READWRITE);
+    g_object_class_install_property (
+            object_class,
+            PROP_THUMBNAIL_SIZE,
+            pspec);
 }
 
 /**
@@ -629,15 +652,15 @@ rstto_settings_set_property    (GObject      *object,
 
     switch (property_id)
     {
-        case PROP_SHOW_FILE_TOOLBAR:
-            settings->priv->show_file_toolbar = g_value_get_boolean (value);
-            break;
-        case PROP_SHOW_NAV_TOOLBAR:
-            settings->priv->show_nav_toolbar = g_value_get_boolean (value);
+        case PROP_SHOW_TOOLBAR:
+            settings->priv->show_toolbar = g_value_get_boolean (value);
             break;
         case PROP_SHOW_THUMBNAILBAR:
             settings->priv->show_thumbnailbar = g_value_get_boolean (value);
             break;
+        case PROP_SHOW_STATUSBAR:
+            settings->priv->show_statusbar = g_value_get_boolean (value);
+            break;
         case PROP_HIDE_THUMBNAILBAR_FULLSCREEN:
             settings->priv->hide_thumbnailbar_fullscreen = g_value_get_boolean (value);
             break;
@@ -709,6 +732,9 @@ rstto_settings_set_property    (GObject      *object,
         case PROP_SORT_TYPE:
             settings->priv->sort_type = g_value_get_uint ( value );
             break;
+        case PROP_THUMBNAIL_SIZE:
+            settings->priv->thumbnail_size = g_value_get_uint (value);
+            break;
         default:
             break;
     }
@@ -725,15 +751,15 @@ rstto_settings_get_property    (GObject    *object,
 
     switch (property_id)
     {
-        case PROP_SHOW_FILE_TOOLBAR:
-            g_value_set_boolean (value, settings->priv->show_file_toolbar);
-            break;
-        case PROP_SHOW_NAV_TOOLBAR:
-            g_value_set_boolean (value, settings->priv->show_nav_toolbar);
+        case PROP_SHOW_TOOLBAR:
+            g_value_set_boolean (value, settings->priv->show_toolbar);
             break;
         case PROP_SHOW_THUMBNAILBAR:
             g_value_set_boolean (value, settings->priv->show_thumbnailbar);
             break;
+        case PROP_SHOW_STATUSBAR:
+            g_value_set_boolean (value, settings->priv->show_statusbar);
+            break;
         case PROP_HIDE_THUMBNAILBAR_FULLSCREEN:
             g_value_set_boolean (value, settings->priv->hide_thumbnailbar_fullscreen);
             break;
@@ -789,6 +815,11 @@ rstto_settings_get_property    (GObject    *object,
                     value,
                     settings->priv->sort_type);
             break;
+        case PROP_THUMBNAIL_SIZE:
+            g_value_set_uint (
+                    value,
+                    settings->priv->thumbnail_size);
+            break;
         default:
             break;
 
